==> xfmail-1.4.4.tar.bz2: xfmail-1.4.4/config/acconfig.h <==
/*
 * Copyright(c) 1995,1996 by Gennady B. Sorokopud (gena@NetVision.net.il)
 *
 * This software can be freely redistributed and modified for
 * non-commercial purposes as long as above copyright
 * message and this permission notice appear in all
 * copies of distributed source code and included as separate file
 * in binary distribution.
 *
 * Any commercial use of this software requires author's permission.
 *
 * This software is provided "as is" without expressed or implied
 * warranty of any kind.
 * Under no circumstances is the author responsible for the proper
 * functioning of this software, nor does the author assume any
 * responsibility for damages incurred with its use.
 *
 */

/* $Id: acconfig.h,v 1.5 1999/12/04 23:50:15 xfmail Exp $
 */

#ifndef CONFIG_H
    #define CONFIG_H

@TOP@

/* some systems do not have XReadBitmapFileData */
    #undef  HAVE_XREADBITMAPFILEDATE

/* see which DBM code to use, Berkley or GNU */
    #undef  USE_NDBM

/* see which DBM code to use, Berkley or GNU */
    #undef  USE_GDBM

/* see if we have WMaker.h for docking code  */
    #undef  HAVE_WMAKER

/* some systems does not have XSupportsLocale */
    #undef  HAVE_XSUPPORTSLOCALE

/* Where new mail is spooled */
    #undef _CONF_PATH_MAILDIR

/* How to print */
    #undef _PATH_LPR
    #undef _PATH_LP

/* Where sendmail lives */
    #undef _CONF_PATH_SENDMAIL

/* Where to find pgp executable */
    #undef _PATH_PGP

/* Where to find ispell executable */
    #undef _PATH_ISPELL

/* Where to find rm executable */
    #undef _PATH_RM

@BOTTOM@

    #if defined(__SVR4) || defined(__svr4__)
        #define SVR4
    #endif

    #if defined(__STDC__)
        #define USE_STDARG
    #endif

    #if defined(SCO)
        #define MAXPATHLEN  PATHSIZE
    #endif

#endif

==> xfmail-1.4.6.tar.bz2: xfmail-1.4.6/config/acconfig.h <==
/* $Id: acconfig.h,v 1.9 2000/05/04 05:39:00 cfreeze Exp $
 */

#ifndef CONFIG_H
    #define CONFIG_H

@TOP@

/* some systems do not have crypto support */
    #undef  USE_GPASSWD

/* some systems do not have pthread support */
    #undef  USE_THREADS

/* some systems do not have dmalloc installed */
/* some systems do not have dmalloc installed */
    #undef  HAVE_DMALLOC
	#ifdef HAVE_DMALLOC
		#include <dmalloc.h>
		#define xf_malloc malloc
		#define xf_realloc realloc
		#define xf_free free
	#else
		#include <glib.h>
		#define xf_malloc g_malloc
		#define xf_realloc g_realloc
		#define xf_free g_free
	#endif


/* some systems do not have XReadBitmapFileData */
    #undef  HAVE_XREADBITMAPFILEDATE

/* see which DBM code to use, Berkley or GNU */
    #undef  USE_NDBM

/* see which DBM code to use, Berkley or GNU */
    #undef  USE_GDBM

/* see if we have WMaker.h for docking code  */
    #undef  HAVE_WMAKER

/* some systems does not have XSupportsLocale */
    #undef  HAVE_XSUPPORTSLOCALE

/* Where new mail is spooled */
    #undef _CONF_PATH_MAILDIR

/* How to print */
    #undef _PATH_LPR
    #undef _PATH_LP

/* Where sendmail lives */
    #undef _CONF_PATH_SENDMAIL

/* Where to find pgp executable */
    #undef _PATH_PGP

/* Where to find ispell executable */
    #undef _PATH_ISPELL

/* Where to find rm executable */
    #undef _PATH_RM

@BOTTOM@

    #if defined(__SVR4) || defined(__svr4__)
        #define SVR4
    #endif

    #if defined(__STDC__)
        #define USE_STDARG
    #endif

    #if defined(SCO)
        #define MAXPATHLEN  PATHSIZE
    #endif

#endif
